Software repository for the neutron reflectometer Amor at the Paul Scherrer Institut, Switzerland

reduction of the raw files (.hdf) to reflectivity files in one of the representations of the **ORSO reflectivity file format**:

> `eos.py`  
> `neos.py` : version for playing and testing

visualisation of the content of a raw file (.hdf):

> `events2histogram.py`

#TODO: real readme for final system needed.
